import requests
import lxml.html as lh
import json

def getHtmlResponse(tingkatan,tahun_ajaran,id_tabel='1'):
	content = requests.get('http://statistik.data.kemdikbud.go.id/index.php/statistik/tableLoad/'+tingkatan+'/'+tahun_ajaran+'/000000/0/'+id_tabel)
	doc = lh.fromstring(content.text.replace('\r\n\t\t\t','').replace('\r\n\t\t',''))
	return doc



import requests
import lxml.html as lh
import json
from StatistikPendidikan.get import getHtmlResponse

def getGambaranUmumSekolah(tingkatan,tahun_ajaran):
	doc = getHtmlResponse(tingkatan,tahun_ajaran,"1")
	table_description = doc.xpath('//table/thead/tr')
	table_description = table_description[0:len(table_description)-2]
	extracted_table_data = {}
	extracted_table_data['id_tabel'] = table_description[0].xpath('th')[0].text_content().replace('TABEL / TABLE : ','')
	extracted_table_data['tahun'] = table_description[3].text_content().replace('TAHUN / YEAR : ','')
	extracted_table_data['nama_tabel'] = table_description[1].text_content()
	raw_data = doc.xpath('//table/tbody/tr')
	for data in raw_data:
	  cols = data.xpath('td')
	  if len(cols[0].text_content()) >1:
	    extracted_table_data[cols[1].text_content().split("/")[0].strip()] = {}
	    extracted_table_data[cols[1].text_content().split("/")[0].strip()]['negeri'] = cols[2].text_content().replace(',','')
	    extracted_table_data[cols[1].text_content().split("/")[0].strip()]['swasta'] = cols[4].text_content().replace(',','')
	    extracted_table_data[cols[1].text_content().split("/")[0].strip()]['jumlah'] = cols[6].text_content().replace(',','')
	return extracted_table_data



from distutils.core import setup
setup(
  name = 'StatistikPendidikan',
  packages = ['StatistikPendidikan'],
  version = '0.1.1.2',
  license='MIT',
  description = 'Library ini digunakan untuk memudahkan ekstraksi data dari http://statistik.data.kemdikbud.go.id/',
  author = 'Aryya Widigdha',
  author_email = 'aryya.widigdha@yahoo.com',
  url = 'https://github.com/adwisatya/StatistikPendidikan',
  download_url = 'https://github.com/adwisatya/StatistikPendidikan/archive/refs/tags/v0.1.tar.gz',
  keywords = ['kemendikbud', 'statistik pendidikan', 'KEYWORDS'],
  install_requires=[
          'requests',
	  'lxml.html',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
